You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@reef.apache.org by we...@apache.org on 2015/03/07 01:22:29 UTC

incubator-reef git commit: [REEF-37] Use MaxNumberOfEvaluators instead of NumberOfProcesses

Repository: incubator-reef
Updated Branches:
  refs/heads/master 6c6ad3367 -> 5391397a1


[REEF-37] Use MaxNumberOfEvaluators instead of NumberOfProcesses

  * Change the class name from NumberOfProcesses to
    MaxNumberOfEvaluators
  * Change related static global variables' names to
    MaxNumberOfEvaluators as well

JIRA:
  [REEF-37] https://issues.apache.org/jira/browse/REEF-37

Pull Request:
  This closes #98


Project: http://git-wip-us.apache.org/repos/asf/incubator-reef/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-reef/commit/5391397a
Tree: http://git-wip-us.apache.org/repos/asf/incubator-reef/tree/5391397a
Diff: http://git-wip-us.apache.org/repos/asf/incubator-reef/diff/5391397a

Branch: refs/heads/master
Commit: 5391397a186780aecc6df4fbcfbbfccb4d08902d
Parents: 6c6ad33
Author: John Yang <jo...@apache.org>
Authored: Tue Mar 3 17:20:21 2015 +0900
Committer: Markus Weimer <we...@apache.org>
Committed: Fri Mar 6 16:13:43 2015 -0800

----------------------------------------------------------------------
 .../apache/reef/javabridge/generic/Launch.java  |  7 ++---
 .../apache/reef/examples/helloCLR/HelloCLR.java |  2 +-
 .../reef/examples/retained_evalCLR/Launch.java  |  6 ++--
 .../examples/data/loading/DataLoadingREEF.java  |  8 ++++--
 .../reef/examples/group/bgd/BGDLocal.java       |  4 +--
 .../examples/group/broadcast/BroadcastREEF.java |  4 +--
 .../apache/reef/examples/hello/HelloREEF.java   |  8 ++++--
 .../reef/examples/hello/HelloREEFNoClient.java  |  2 +-
 .../reef/examples/hellohttp/HelloREEFHttp.java  |  7 ++++-
 .../org/apache/reef/examples/pool/Launch.java   |  6 ++--
 .../reef/examples/retained_eval/Launch.java     |  6 ++--
 .../reef/examples/scheduler/SchedulerREEF.java  |  6 +++-
 .../apache/reef/examples/suspend/Launch.java    |  6 ++--
 .../reef/examples/hello/HelloHttpTest.java      |  2 +-
 .../client/DriverConfigurationProvider.java     | 10 +++----
 .../local/client/LocalJobSubmissionHandler.java |  1 -
 .../local/client/LocalRuntimeConfiguration.java |  6 ++--
 .../parameters/MaxNumberOfEvaluators.java       | 29 ++++++++++++++++++++
 .../client/parameters/NumberOfProcesses.java    | 29 --------------------
 .../runtime/local/driver/ContainerManager.java  |  4 +--
 .../local/driver/LocalDriverConfiguration.java  |  8 +++---
 .../reef/tests/yarn/failure/FailureREEF.java    |  8 ++++--
 .../apache/reef/tests/LocalTestEnvironment.java |  8 +++---
 .../tests/examples/TestRetainedEvaluators.java  |  2 +-
 .../multipleEventHandlerInstances/Client.java   |  2 +-
 25 files changed, 99 insertions(+), 82 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-bridge-java/src/main/java/org/apache/reef/javabridge/generic/Launch.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-bridge-java/src/main/java/org/apache/reef/javabridge/generic/Launch.java b/lang/java/reef-bridge-java/src/main/java/org/apache/reef/javabridge/generic/Launch.java
index b1473ee..f3f5fae 100644
--- a/lang/java/reef-bridge-java/src/main/java/org/apache/reef/javabridge/generic/Launch.java
+++ b/lang/java/reef-bridge-java/src/main/java/org/apache/reef/javabridge/generic/Launch.java
@@ -32,7 +32,6 @@ import org.apache.reef.tang.exceptions.InjectionException;
 import org.apache.reef.tang.formats.CommandLine;
 import org.apache.reef.util.logging.LoggingScope;
 import org.apache.reef.util.logging.LoggingScopeFactory;
-import org.apache.reef.util.logging.LoggingScopeImpl;
 
 import java.io.File;
 import java.io.IOException;
@@ -47,9 +46,9 @@ import java.util.logging.Logger;
 public final class Launch {
 
   /**
-   * Number of REEF worker threads in local mode. We assume maximum 10 evaluators can be requested on local runtime
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  private static final int NUM_LOCAL_THREADS = 10;
+  private static final int MAX_NUMBER_OF_EVALUATORS = 10;
   /**
    * Standard Java logger
    */
@@ -122,7 +121,7 @@ public final class Launch {
       if (isLocal) {
         LOG.log(Level.INFO, "Running on the local runtime");
         runtimeConfiguration = LocalRuntimeConfiguration.CONF
-            .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+            .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
             .build();
       } else {
         LOG.log(Level.INFO, "Running on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/helloCLR/HelloCLR.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/helloCLR/HelloCLR.java b/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/helloCLR/HelloCLR.java
index f8ff247..7ee851e 100644
--- a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/helloCLR/HelloCLR.java
+++ b/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/helloCLR/HelloCLR.java
@@ -83,7 +83,7 @@ public final class HelloCLR {
    */
   public static void main(final String[] args) throws BindException, InjectionException {
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 2)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, 2)
         .build();
 
     final File dotNetFolder = new File(args[0]).getAbsoluteFile();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/retained_evalCLR/Launch.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/retained_evalCLR/Launch.java b/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/retained_evalCLR/Launch.java
index 97c39c3..66dbe92 100644
--- a/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/retained_evalCLR/Launch.java
+++ b/lang/java/reef-examples-clr/src/main/java/org/apache/reef/examples/retained_evalCLR/Launch.java
@@ -46,9 +46,9 @@ import java.util.logging.Logger;
 public final class Launch {
 
   /**
-   * Number of REEF worker threads in local mode.
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  private static final int NUM_LOCAL_THREADS = JobDriver.totalEvaluators;
+  private static final int MAX_NUMBER_OF_EVALUATORS = JobDriver.totalEvaluators;
   /**
    * Standard Java logger
    */
@@ -118,7 +118,7 @@ public final class Launch {
     if (isLocal) {
       LOG.log(Level.INFO, "Running on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/data/loading/DataLoadingREEF.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/data/loading/DataLoadingREEF.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/data/loading/DataLoadingREEF.java
index a6e7544..e1ccbcc 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/data/loading/DataLoadingREEF.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/data/loading/DataLoadingREEF.java
@@ -50,7 +50,11 @@ public class DataLoadingREEF {
 
   private static final Logger LOG = Logger.getLogger(DataLoadingREEF.class.getName());
 
-  private static final int NUM_LOCAL_THREADS = 16;
+  /**
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
+   */
+  private static final int MAX_NUMBER_OF_EVALUATORS = 16;
+
   private static final int NUM_SPLITS = 6;
   private static final int NUM_COMPUTE_EVALUATORS = 2;
 
@@ -77,7 +81,7 @@ public class DataLoadingREEF {
     if (isLocal) {
       LOG.log(Level.INFO, "Running Data Loading demo on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running Data Loading demo on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/bgd/BGDLocal.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/bgd/BGDLocal.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/bgd/BGDLocal.java
index 3a82314..69a3f5d 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/bgd/BGDLocal.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/bgd/BGDLocal.java
@@ -33,7 +33,7 @@ public class BGDLocal {
 
   private static final Logger LOG = Logger.getLogger(BGDLocal.class.getName());
 
-  private static final int NUM_LOCAL_THREADS = 20;
+  private static final int MAX_NUMBER_OF_EVALUATORS = 20;
   private static final int TIMEOUT = 10 * Timer.MINUTES;
 
   public static void main(final String[] args) throws Exception {
@@ -41,7 +41,7 @@ public class BGDLocal {
     final BGDClient bgdClient = BGDClient.fromCommandLine(args);
 
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, "" + NUM_LOCAL_THREADS)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, "" + MAX_NUMBER_OF_EVALUATORS)
         .build();
 
     final String jobName = System.getProperty("user.name") + "-" + "ResourceAwareBGDLocal";

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/broadcast/BroadcastREEF.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/broadcast/BroadcastREEF.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/broadcast/BroadcastREEF.java
index cac6ccd..839bea4 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/broadcast/BroadcastREEF.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/group/broadcast/BroadcastREEF.java
@@ -46,7 +46,7 @@ import java.util.logging.Logger;
 public class BroadcastREEF {
   private static final Logger LOG = Logger.getLogger(BroadcastREEF.class.getName());
 
-  private static final String NUM_LOCAL_THREADS = "20";
+  private static final String MAX_NUMBER_OF_EVALUATORS = "20";
 
   /**
    * Number of milliseconds to wait for the job to complete.
@@ -103,7 +103,7 @@ public class BroadcastREEF {
     if (local) {
       LOG.log(Level.INFO, "Running Broadcast example using group API on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running Broadcast example using group API on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEF.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEF.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEF.java
index ffaa304..6a23274 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEF.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEF.java
@@ -34,10 +34,14 @@ import java.util.logging.Logger;
  * The Client for Hello REEF example.
  */
 public final class HelloREEF {
-
   private static final Logger LOG = Logger.getLogger(HelloREEF.class.getName());
 
   /**
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
+   */
+  private static final int MAX_NUMBER_OF_EVALUATORS = 2;
+
+  /**
    * Number of milliseconds to wait for the job to complete.
    */
   private static final int JOB_TIMEOUT = 10000; // 10 sec.
@@ -69,7 +73,7 @@ public final class HelloREEF {
    */
   public static void main(final String[] args) throws BindException, InjectionException {
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 2)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
         .build();
     final LauncherStatus status = runHelloReef(runtimeConfiguration, JOB_TIMEOUT);
     LOG.log(Level.INFO, "REEF job completed: {0}", status);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEFNoClient.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEFNoClient.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEFNoClient.java
index 066b336..7ed78f6 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEFNoClient.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hello/HelloREEFNoClient.java
@@ -55,7 +55,7 @@ public final class HelloREEFNoClient {
   public static void main(final String[] args) throws BindException, InjectionException {
 
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 2)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, 2)
         .build();
 
     runHelloReefWithoutClient(runtimeConfiguration);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hellohttp/HelloREEFHttp.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hellohttp/HelloREEFHttp.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hellohttp/HelloREEFHttp.java
index a92499f..086943d 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hellohttp/HelloREEFHttp.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/hellohttp/HelloREEFHttp.java
@@ -39,6 +39,11 @@ import java.util.logging.Logger;
  */
 public final class HelloREEFHttp {
   /**
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
+   */
+  private static final int MAX_NUMBER_OF_EVALUATORS = 3;
+
+  /**
    * Number of milliseconds to wait for the job to complete.
    */
   public static final int JOB_TIMEOUT = 60 * 1000; // 60 sec.
@@ -105,7 +110,7 @@ public final class HelloREEFHttp {
    */
   public static void main(final String[] args) throws InjectionException {
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 3)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
         .build();
     final LauncherStatus status = runHelloReef(runtimeConfiguration, HelloREEFHttp.JOB_TIMEOUT);
   }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/pool/Launch.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/pool/Launch.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/pool/Launch.java
index af8f455..6c832c0 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/pool/Launch.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/pool/Launch.java
@@ -44,9 +44,9 @@ import java.util.logging.Logger;
 public final class Launch {
 
   /**
-   * Number of REEF worker threads in local mode.
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  private static final int NUM_LOCAL_THREADS = 4;
+  private static final int MAX_NUMBER_OF_EVALUATORS = 4;
   /**
    * Standard Java logger
    */
@@ -107,7 +107,7 @@ public final class Launch {
     if (isLocal) {
       LOG.log(Level.FINE, "Running on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.FINE, "Running on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/retained_eval/Launch.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/retained_eval/Launch.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/retained_eval/Launch.java
index cf230bc..4fbe397 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/retained_eval/Launch.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/retained_eval/Launch.java
@@ -43,9 +43,9 @@ import java.util.logging.Logger;
 public final class Launch {
 
   /**
-   * Number of REEF worker threads in local mode.
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  private static final int NUM_LOCAL_THREADS = 4;
+  private static final int MAX_NUMBER_OF_EVALUATORS = 4;
   /**
    * Standard Java logger
    */
@@ -117,7 +117,7 @@ public final class Launch {
     if (isLocal) {
       LOG.log(Level.INFO, "Running on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEF.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEF.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEF.java
index 2911905..80c9096 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEF.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEF.java
@@ -38,6 +38,10 @@ import java.io.IOException;
  * REEF TaskScheduler.
  */
 public final class SchedulerREEF {
+  /**
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
+   */
+  private static final int MAX_NUMBER_OF_EVALUATORS = 3;
 
   /**
    * Command line parameter = true to reuse evaluators,
@@ -102,7 +106,7 @@ public final class SchedulerREEF {
    */
   public final static void main(String[] args) throws InjectionException, IOException, ParseException {
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-      .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 3)
+      .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
       .build();
     runTaskScheduler(runtimeConfiguration, args);
   }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/suspend/Launch.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/suspend/Launch.java b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/suspend/Launch.java
index 696d02d..3a64b9b 100644
--- a/lang/java/reef-examples/src/main/java/org/apache/reef/examples/suspend/Launch.java
+++ b/lang/java/reef-examples/src/main/java/org/apache/reef/examples/suspend/Launch.java
@@ -46,9 +46,9 @@ public final class Launch {
    */
   private static final Logger LOG = Logger.getLogger(Launch.class.getName());
   /**
-   * Number of REEF worker threads in local mode.
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  private static final int NUM_LOCAL_THREADS = 4;
+  private static final int MAX_NUMBER_OF_EVALUATORS = 4;
 
   /**
    * This class should not be instantiated.
@@ -111,7 +111,7 @@ public final class Launch {
     if (isLocal) {
       LOG.log(Level.INFO, "Running on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-examples/src/test/java/org/apache/reef/examples/hello/HelloHttpTest.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-examples/src/test/java/org/apache/reef/examples/hello/HelloHttpTest.java b/lang/java/reef-examples/src/test/java/org/apache/reef/examples/hello/HelloHttpTest.java
index 14812ca..2f711b3 100644
--- a/lang/java/reef-examples/src/test/java/org/apache/reef/examples/hello/HelloHttpTest.java
+++ b/lang/java/reef-examples/src/test/java/org/apache/reef/examples/hello/HelloHttpTest.java
@@ -32,7 +32,7 @@ public class HelloHttpTest {
   public void testHttpServer() throws BindException, InjectionException {
 
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 2)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, 2)
         .build();
 
     final LauncherStatus status = HelloREEFHttp.runHelloReef(runtimeConfiguration, 10 * 1000);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/DriverConfigurationProvider.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/DriverConfigurationProvider.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/DriverConfigurationProvider.java
index a9ad172..e22a7d5 100644
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/DriverConfigurationProvider.java
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/DriverConfigurationProvider.java
@@ -19,7 +19,7 @@
 package org.apache.reef.runtime.local.client;
 
 import org.apache.reef.runtime.common.parameters.JVMHeapSlack;
-import org.apache.reef.runtime.local.client.parameters.NumberOfProcesses;
+import org.apache.reef.runtime.local.client.parameters.MaxNumberOfEvaluators;
 import org.apache.reef.runtime.local.driver.LocalDriverConfiguration;
 import org.apache.reef.tang.Configuration;
 import org.apache.reef.tang.Configurations;
@@ -33,13 +33,13 @@ import java.io.File;
  */
 public final class DriverConfigurationProvider {
 
-  private final int nThreads;
+  private final int maxEvaluators;
   private final double jvmHeapSlack;
 
   @Inject
-  DriverConfigurationProvider(final @Parameter(NumberOfProcesses.class) int nThreads,
+  DriverConfigurationProvider(final @Parameter(MaxNumberOfEvaluators.class) int maxEvaluators,
                               final @Parameter(JVMHeapSlack.class) double jvmHeapSlack) {
-    this.nThreads = nThreads;
+    this.maxEvaluators = maxEvaluators;
     this.jvmHeapSlack = jvmHeapSlack;
   }
 
@@ -47,7 +47,7 @@ public final class DriverConfigurationProvider {
                                                final String clientRemoteId,
                                                final String jobId) {
     return LocalDriverConfiguration.CONF
-        .set(LocalDriverConfiguration.NUMBER_OF_PROCESSES, this.nThreads)
+        .set(LocalDriverConfiguration.MAX_NUMBER_OF_EVALUATORS, this.maxEvaluators)
         .set(LocalDriverConfiguration.ROOT_FOLDER, jobFolder.getAbsolutePath())
         .set(LocalDriverConfiguration.JVM_HEAP_SLACK, this.jvmHeapSlack)
         .set(LocalDriverConfiguration.CLIENT_REMOTE_IDENTIFIER, clientRemoteId)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalJobSubmissionHandler.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalJobSubmissionHandler.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalJobSubmissionHandler.java
index 8a63af9..75fc86e 100644
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalJobSubmissionHandler.java
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalJobSubmissionHandler.java
@@ -27,7 +27,6 @@ import org.apache.reef.runtime.common.files.ClasspathProvider;
 import org.apache.reef.runtime.common.files.REEFFileNames;
 import org.apache.reef.runtime.common.launch.JavaLaunchCommandBuilder;
 import org.apache.reef.runtime.local.client.parameters.RootFolder;
-import org.apache.reef.runtime.local.driver.LocalDriverConfiguration;
 import org.apache.reef.runtime.local.process.LoggingRunnableProcessObserver;
 import org.apache.reef.runtime.local.process.RunnableProcess;
 import org.apache.reef.tang.Configuration;

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalRuntimeConfiguration.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalRuntimeConfiguration.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalRuntimeConfiguration.java
index fe7f104..a5d94dd 100644
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalRuntimeConfiguration.java
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/LocalRuntimeConfiguration.java
@@ -27,7 +27,7 @@ import org.apache.reef.runtime.common.files.RuntimeClasspathProvider;
 import org.apache.reef.runtime.common.launch.REEFMessageCodec;
 import org.apache.reef.runtime.common.parameters.JVMHeapSlack;
 import org.apache.reef.runtime.local.LocalClasspathProvider;
-import org.apache.reef.runtime.local.client.parameters.NumberOfProcesses;
+import org.apache.reef.runtime.local.client.parameters.MaxNumberOfEvaluators;
 import org.apache.reef.runtime.local.client.parameters.RootFolder;
 import org.apache.reef.tang.formats.ConfigurationModule;
 import org.apache.reef.tang.formats.ConfigurationModuleBuilder;
@@ -47,7 +47,7 @@ public class LocalRuntimeConfiguration extends ConfigurationModuleBuilder {
    * terms of the number of slots available on it with one important caveat: The Driver is not counted against this
    * number.
    */
-  public static final OptionalParameter<Integer> NUMBER_OF_THREADS = new OptionalParameter<>();
+  public static final OptionalParameter<Integer> MAX_NUMBER_OF_EVALUATORS = new OptionalParameter<>();
   /**
    * The folder in which the sub-folders, one per Node, will be created. Those will contain one folder per
    * Evaluator instantiated on the virtual node. Those inner folders will be named by the time when the Evaluator was
@@ -72,7 +72,7 @@ public class LocalRuntimeConfiguration extends ConfigurationModuleBuilder {
       .bindConstructor(ExecutorService.class, ExecutorServiceConstructor.class)
           // Bind the message codec for REEF.
       .bindNamedParameter(RemoteConfiguration.MessageCodec.class, REEFMessageCodec.class)
-      .bindNamedParameter(NumberOfProcesses.class, NUMBER_OF_THREADS)
+      .bindNamedParameter(MaxNumberOfEvaluators.class, MAX_NUMBER_OF_EVALUATORS)
       .bindNamedParameter(RootFolder.class, RUNTIME_ROOT_FOLDER)
       .bindNamedParameter(JVMHeapSlack.class, JVM_HEAP_SLACK)
       .bindImplementation(RuntimeClasspathProvider.class, LocalClasspathProvider.class)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/MaxNumberOfEvaluators.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/MaxNumberOfEvaluators.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/MaxNumberOfEvaluators.java
new file mode 100644
index 0000000..316a659
--- /dev/null
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/MaxNumberOfEvaluators.java
@@ -0,0 +1,29 @@
+/**
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.reef.runtime.local.client.parameters;
+
+import org.apache.reef.tang.annotations.Name;
+import org.apache.reef.tang.annotations.NamedParameter;
+
+/**
+ * The maximum number of evaluators to allow to run at once
+ */
+@NamedParameter(default_value = "4", doc = "The maximum number of evaluators to allow to run at once", short_name = "maxEvaluators")
+public final class MaxNumberOfEvaluators implements Name<Integer> {
+}

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/NumberOfProcesses.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/NumberOfProcesses.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/NumberOfProcesses.java
deleted file mode 100644
index be0e5d4..0000000
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/client/parameters/NumberOfProcesses.java
+++ /dev/null
@@ -1,29 +0,0 @@
-/**
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-package org.apache.reef.runtime.local.client.parameters;
-
-import org.apache.reef.tang.annotations.Name;
-import org.apache.reef.tang.annotations.NamedParameter;
-
-/**
- * The maximum number of processes to use at once
- */
-@NamedParameter(default_value = "4", doc = "The maximum number of processes to use at once", short_name = "nThreads")
-public final class NumberOfProcesses implements Name<Integer> {
-}

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/ContainerManager.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/ContainerManager.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/ContainerManager.java
index 11fb21c..c1a746c 100644
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/ContainerManager.java
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/ContainerManager.java
@@ -26,7 +26,7 @@ import org.apache.reef.proto.ReefServiceProtos;
 import org.apache.reef.runtime.common.driver.api.RuntimeParameters;
 import org.apache.reef.runtime.common.files.REEFFileNames;
 import org.apache.reef.runtime.common.utils.RemoteManager;
-import org.apache.reef.runtime.local.client.parameters.NumberOfProcesses;
+import org.apache.reef.runtime.local.client.parameters.MaxNumberOfEvaluators;
 import org.apache.reef.runtime.local.client.parameters.RootFolder;
 import org.apache.reef.runtime.local.process.ReefRunnableProcessObserver;
 import org.apache.reef.tang.annotations.Parameter;
@@ -78,7 +78,7 @@ final class ContainerManager implements AutoCloseable {
       final RemoteManager remoteManager,
       final RuntimeClock clock,
       final REEFFileNames fileNames,
-      final @Parameter(NumberOfProcesses.class) int capacity,
+      final @Parameter(MaxNumberOfEvaluators.class) int capacity,
       final @Parameter(RootFolder.class) String rootFolderName,
       final @Parameter(RuntimeParameters.NodeDescriptorHandler.class)
       EventHandler<DriverRuntimeProtocol.NodeDescriptorProto> nodeDescriptorHandler,

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/LocalDriverConfiguration.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-tests/src/main/java/org/apache/reef/tests/yarn/failure/FailureREEF.java b/lang/java/reef-tests/src/main/java/org/apache/reef/tests/yarn/failure/FailureREEF.java
index aa4b5fd..268e462 100644
--- a/lang/java/reef-tests/src/main/java/org/apache/reef/tests/yarn/failure/FailureREEF.java
+++ b/lang/java/reef-tests/src/main/java/org/apache/reef/tests/yarn/failure/FailureREEF.java
@@ -39,8 +39,10 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 
 public final class FailureREEF {
-
-  public static final int NUM_LOCAL_THREADS = 16;
+  /**
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
+   */
+  public static final int MAX_NUMBER_OF_EVALUATORS = 16;
 
   private static final Logger LOG = Logger.getLogger(FailureREEF.class.getName());
 
@@ -71,7 +73,7 @@ public final class FailureREEF {
     if (isLocal) {
       LOG.log(Level.INFO, "Running Failure demo on the local runtime");
       runtimeConfiguration = LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUM_LOCAL_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       LOG.log(Level.INFO, "Running Failure demo on YARN");

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/LocalTestEnvironment.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/LocalTestEnvironment.java b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/LocalTestEnvironment.java
index 345b49c..c1efb88 100644
--- a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/LocalTestEnvironment.java
+++ b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/LocalTestEnvironment.java
@@ -27,9 +27,9 @@ import org.apache.reef.tang.Configuration;
 public final class LocalTestEnvironment extends TestEnvironmentBase implements TestEnvironment {
 
   /**
-   * The number of threads allocated to the local runtime.
+   * The upper limit on the number of Evaluators that the local resourcemanager will hand out concurrently
    */
-  public static final int NUMBER_OF_THREADS = 4;
+  public static final int MAX_NUMBER_OF_EVALUATORS = 4;
   // Used to make sure the tests call the methods in the right order.
   private boolean ready = false;
 
@@ -44,11 +44,11 @@ public final class LocalTestEnvironment extends TestEnvironmentBase implements T
     final String rootFolder = System.getProperty("org.apache.reef.runtime.local.folder");
     if (null == rootFolder) {
       return LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUMBER_OF_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .build();
     } else {
       return LocalRuntimeConfiguration.CONF
-          .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, NUMBER_OF_THREADS)
+          .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, MAX_NUMBER_OF_EVALUATORS)
           .set(LocalRuntimeConfiguration.RUNTIME_ROOT_FOLDER, rootFolder)
           .build();
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/examples/TestRetainedEvaluators.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/examples/TestRetainedEvaluators.java b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/examples/TestRetainedEvaluators.java
index 36397f5..a563eab 100644
--- a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/examples/TestRetainedEvaluators.java
+++ b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/examples/TestRetainedEvaluators.java
@@ -50,7 +50,7 @@ public final class TestRetainedEvaluators {
    */
   private static Configuration getLaunchConfiguration() {
     return Tang.Factory.getTang().newConfigurationBuilder()
-        .bindNamedParameter(Launch.NumEval.class, "" + (LocalTestEnvironment.NUMBER_OF_THREADS - 1))
+        .bindNamedParameter(Launch.NumEval.class, "" + (LocalTestEnvironment.MAX_NUMBER_OF_EVALUATORS - 1))
         .bindNamedParameter(Launch.NumRuns.class, "2")
         .bindNamedParameter(Command.class, "echo " + MESSAGE)
         .build();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/multipleEventHandlerInstances/Client.java
----------------------------------------------------------------------
diff --git a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/multipleEventHandlerInstances/Client.java b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/multipleEventHandlerInstances/Client.java
index 5345fe6..b94cc39 100644
--- a/lang/java/reef-tests/src/test/java/org/apache/reef/tests/multipleEventHandlerInstances/Client.java
+++ b/lang/java/reef-tests/src/test/java/org/apache/reef/tests/multipleEventHandlerInstances/Client.java
@@ -68,7 +68,7 @@ public class Client {
   @Test
   public void testMultipleInstances() throws BindException, InjectionException {
     final Configuration runtimeConfiguration = LocalRuntimeConfiguration.CONF
-        .set(LocalRuntimeConfiguration.NUMBER_OF_THREADS, 2)
+        .set(LocalRuntimeConfiguration.MAX_NUMBER_OF_EVALUATORS, 2)
         .build();
     final LauncherStatus status = runReefJob(runtimeConfiguration, JOB_TIMEOUT);
     Assert.assertTrue("Reef Job MultipleHandlerInstances failed: " + status, status.isSuccess());
diff --git a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/LocalDriverConfiguration.java b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/LocalDriverConfiguration.java
index 8258567..1db7503 100644
--- a/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/LocalDriverConfiguration.java
+++ b/lang/java/reef-runtime-local/src/main/java/org/apache/reef/runtime/local/driver/LocalDriverConfiguration.java
@@ -25,7 +25,7 @@ import org.apache.reef.runtime.common.driver.api.ResourceRequestHandler;
 import org.apache.reef.runtime.common.files.RuntimeClasspathProvider;
 import org.apache.reef.runtime.common.parameters.JVMHeapSlack;
 import org.apache.reef.runtime.local.LocalClasspathProvider;
-import org.apache.reef.runtime.local.client.parameters.NumberOfProcesses;
+import org.apache.reef.runtime.local.client.parameters.MaxNumberOfEvaluators;
 import org.apache.reef.runtime.local.client.parameters.RootFolder;
 import org.apache.reef.tang.formats.ConfigurationModule;
 import org.apache.reef.tang.formats.ConfigurationModuleBuilder;
@@ -38,9 +38,9 @@ import org.apache.reef.tang.formats.RequiredParameter;
  */
 public class LocalDriverConfiguration extends ConfigurationModuleBuilder {
   /**
    * The maximum number or processes to spawn.
    */
-  public static final RequiredParameter<Integer> NUMBER_OF_PROCESSES = new RequiredParameter<>();
+  public static final RequiredParameter<Integer> MAX_NUMBER_OF_EVALUATORS = new RequiredParameter<>();
   /**
    * The root folder of the job. Assumed to be an absolute path.
    */
@@ -66,7 +66,7 @@ public class LocalDriverConfiguration extends ConfigurationModuleBuilder {
       .bindImplementation(ResourceReleaseHandler.class, LocalResourceReleaseHandler.class)
       .bindNamedParameter(AbstractDriverRuntimeConfiguration.ClientRemoteIdentifier.class, CLIENT_REMOTE_IDENTIFIER)
       .bindNamedParameter(AbstractDriverRuntimeConfiguration.JobIdentifier.class, JOB_IDENTIFIER)
-      .bindNamedParameter(NumberOfProcesses.class, NUMBER_OF_PROCESSES)
+      .bindNamedParameter(MaxNumberOfEvaluators.class, MAX_NUMBER_OF_EVALUATORS)
       .bindNamedParameter(RootFolder.class, ROOT_FOLDER)
       .bindNamedParameter(JVMHeapSlack.class, JVM_HEAP_SLACK)
       .bindImplementation(RuntimeClasspathProvider.class, LocalClasspathProvider.class)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/5391397a/lang/java/reef-tests/src/main/java/org/apache/reef/tests/yarn/failure/FailureREEF.java
----------------------------------------------------------------------
@@ -38,9 +38,9 @@ import org.apache.reef.tang.formats.RequiredParameter;
 public class LocalDriverConfiguration extends ConfigurationModuleBuilder {
   /**
-   * The maximum number or processes to spawn.
+   * The maximum number of evaluators.
    */